slepc-3.18.0 2022-10-01
Report Typos and Errors

# STCayleyGetAntishift

Gets the value of the anti-shift used in the Cayley spectral transformation.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STCayleyGetAntishift(ST st,PetscScalar *nu)

Not Collective

### Input Parameter

| st | - the spectral transformation context

### Output Parameter

| nu | - the anti-shift

### See Also

STGetShift(), STCayleySetAntishift()

### Level

intermediate

### Location

src/sys/classes/st/impls/cayley/cayley.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages